local _, A = ...

-- INTERFACE OPTIONS PANEL
function A:CreateOptionsMenu()
  local optionsPanel = CreateFrame("Frame", "AutoMailerOptions", UIParent)
  optionsPanel.name = "AutoMailer"
  InterfaceOptions_AddCategory(optionsPanel)

  local text = optionsPanel:CreateFontString(nil, "OVERLAY")
  text:SetFontObject("GameFontNormalHuge")
  text:SetText("AutoMailer Options")
  text:SetPoint("TOPLEFT", optionsPanel, "TOPLEFT", 20, -10)

  local recipientHeader = optionsPanel:CreateFontString(nil, "OVERLAY")
  recipientHeader:SetFontObject("GameFontNormal")
  recipientHeader:SetText("Recipient")
  recipientHeader:SetPoint("TOPLEFT", text, "BOTTOMLEFT", 0, -15)


  local loginMessage = CreateFrame("CheckButton", nil, optionsPanel, "UICheckButtonTemplate")
  loginMessage:SetSize(25,25)
  loginMessage:SetPoint("BOTTOMLEFT", optionsPanel, "BOTTOMLEFT", 10, 3)
  loginMessage:SetScript("OnClick", function(self, button)
    AutoMailer.loginMessage = self:GetChecked()
  end)
  loginMessage:SetChecked(AutoMailer.loginMessage)
  optionsPanel.loginMessage = loginMessage

  local loginMessageText = loginMessage:CreateFontString(nil, "OVERLAY")
  loginMessageText:SetFontObject("GameFontNormal")
  loginMessageText:SetPoint("LEFT", loginMessage, "RIGHT", 3, 0)
  loginMessageText:SetText("Display login message")
  optionsPanel.loginMessageText = loginMessageText


  local recipientBox = CreateFrame("EditBox", "recipientBox", optionsPanel, "InputBoxTemplate")
  recipientBox:SetPoint("TOPLEFT", recipientHeader, "BOTTOMLEFT", 0, -5)
  recipientBox:SetSize(200, 30)
  recipientBox:SetFontObject("ChatFontNormal")
  recipientBox:SetMultiLine(false)
  recipientBox:SetText(AutoMailer.recipient)
  recipientBox:SetCursorPosition(0)
  recipientBox:SetAutoFocus(false)
  recipientBox:SetScript("OnEscapePressed", function(self) self:ClearFocus() end)
  recipientBox:SetScript("OnKeyUp", function(self)
    AutoMailer.recipient = self:GetText()
  end)
  recipientBox:SetScript("OnEnterPressed", function(self)
    AutoMailer.recipient = self:GetText()
    self:ClearFocus()
  end)
  
  optionsPanel.recipientBox = recipientBox

  local itemsHeader = optionsPanel:CreateFontString(nil, "OVERLAY")
  itemsHeader:SetPoint("TOPLEFT", recipientBox, "BOTTOMLEFT", 0, -15)
  itemsHeader:SetFontObject("GameFontNormal")
  itemsHeader:SetText("Items to AutoMail")

  optionsPanel.itemsHeader = itemsHeader


  local backdrop = {
    bgFile = "Interface\\TutorialFrame\\TutorialFrameBackground",
    edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border",
    edgeSize = 16,
    tile = true,
    tileSize = 16,
    insets = { left = 4, right = 4, top = 4, bottom = 4 }
  }
  
  local itemsFrame = CreateFrame("ScrollFrame", nil, optionsPanel, "UIPanelScrollFrameTemplate")
  itemsFrame:SetPoint("TOPLEFT", itemsHeader, "BOTTOMLEFT", 0, -5)
  itemsFrame:SetSize(275, 300)

  optionsPanel.itemsFrame = itemsFrame

  local itemsBG = CreateFrame("Frame", nil, optionsPanel)
  itemsBG:SetPoint("CENTER", itemsFrame, "CENTER")
  itemsBG:SetSize(285, 310)
  itemsBG:SetBackdrop(backdrop)


  local items = CreateFrame("EditBox", nil, itemsFrame)
  --items:SetBackdrop(backdrop)
  items:SetFrameStrata("DIALOG")
  items:SetPoint("TOP", itemsFrame, "TOP", 0, -10)
  items:SetFont(GameFontNormal:GetFont(), 12)
  items:SetWidth(265)
  items:SetHeight(300)
  items:SetText(AutoMailer.items)
  items:SetAutoFocus(false)
  items:SetMultiLine(true)
  items:SetScript("OnEscapePressed", function(self) self:ClearFocus() end)
  items:SetScript("OnKeyUp", function(self)
    AutoMailer.items = self:GetText()
  end)

  itemsFrame:SetScrollChild(items)
  optionsPanel.items = items


  local BOECB = CreateFrame("CheckButton", "AMBOECB", optionsPanel, "ChatConfigCheckButtonTemplate")
  BOECB:SetChecked(AutoMailer.SendBOE or false)
  BOECB:SetPoint("TOPLEFT", itemsBG, "TOPRIGHT", 30, 0)
  BOECB:SetScript("OnClick", function(self)
    AutoMailer.SendBOE = self:GetChecked()
  end)
  AutoMailer.SendBOE = BOECB:GetChecked() -- INIT OPTION TO SAVED VARIABLES

  local BOETEXT = BOECB:CreateFontString(nil, "OVERLAY")
  BOETEXT:SetPoint("LEFT", BOECB, "RIGHT", 5, 0)
  BOETEXT:SetFontObject("GameFontNormal")
  BOETEXT:SetText("Automatically send BoEs")

  local BOELEVELLIMIT = CreateFrame("CheckButton", "AMBOELVLLIMITCB", optionsPanel, "ChatConfigCheckButtonTemplate")
  BOELEVELLIMIT:SetChecked(AutoMailer.LimitBoeLevel or true)
  BOELEVELLIMIT:SetPoint("TOPLEFT", BOECB, "BOTTOMLEFT", 5, 0)
  BOELEVELLIMIT:SetScript("OnClick", function(self)
    AutoMailer.LimitBoeLevel = self:GetChecked()
  end)
  AutoMailer.LimitBoeLevel = BOELEVELLIMIT:GetChecked() -- INIT OPTION TO SAVED VARIABLES

  local BOELIMITTEXT = BOELEVELLIMIT:CreateFontString(nil, "OVERLAY")
  BOELIMITTEXT:SetPoint("LEFT", BOELEVELLIMIT, "RIGHT", 5, 0)
  BOELIMITTEXT:SetFontObject("GameFontNormal")
  BOELIMITTEXT:SetText("Only BoEs with required level lower than yours")




  A.optionsPanel = optionsPanel
end
